pub struct TargetPort {
pub id: String,
pub port_type: PortType,
pub service_address: String,
pub network_address: String,
pub physical_address: String,
pub physical_name: String,
pub system_id: String,
/* private fields */
}Expand description
Represent a target port which is the front-end port of storage system which storage user/client connect to and get storage service from.
Fields
id: StringIdentifier.
port_type: PortTypeType of port.
service_address: StringThe address used by upper layer like FC and iSCSI:
-
FC and FCoE: WWPN
-
iSCSI: IQN
The string is in lower case, split with : every two digits if WWPN.
network_address: StringThe address used by network layer like FC and TCP/IP:
-
FC/FCoE: WWPN
-
iSCSI:
IPv4:Portor[IPv6]:Port
The string is in lower case, split with : every two digits if WWPN.
physical_address: StringThe address used by physical layer like FC-0 and MAC:
-
FC and FCoE : WWPN
-
iSCSI: MAC
The string is in Lower case, split with : every two digits.
physical_name: StringThe name of physical port. Administrator could use this name to locate the port on storage system. E.g. ‘eth0’
system_id: StringIdentifier of owner system.